@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: credits.sh,v 1.141 2012/01/08 22:47:10 plm Exp $
+# $Id: credits.sh,v 1.144 2013/03/20 23:51:38 plm Exp $
 # 
 
 authors=/tmp/auth.$$
@@ -37,6 +37,7 @@ Joern Thyssen
 Gary Wong
 Christian Anthon
 Michael Petch
+Philippe Michel
 EOF
 
 cat > $contributors <<EOF
@@ -46,9 +47,9 @@ Nis Joergensen
 Petr Kadlec
 Kaoru Takahashi
 Stein Kulseth
-Philippe Michel
 Rod Roark
 Ingo Macherius
+Guido Flohr
 EOF
 
 cat > $support <<EOF
@@ -95,7 +96,6 @@ Ian Dunstan
 Max Durbano
 Peter Eberhard
 Robert Eberlein
-Guido Flohr
 Fotis
 Kennedy Fraser
 Ric Gerace
@@ -107,7 +107,6 @@ Alain Henry
 Jens Hoefkens
 Casey Hopkins
 Martin Janke
-Nis Jorgensen
 Neil Kazaross
 Mathias Kegelmann
 Matija Kejzar
@@ -258,7 +257,7 @@ cat > credits.c <<EOF
 #include "credits.h"
 
 const char aszCOPYRIGHT[] = N_("Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 by Gary Wong.\n"
-                               "Copyright (C) 2012 by Gary Wong and the AUTHORS; for details type \`show version'.");
+                               "Copyright (C) 2013 by Gary Wong and the AUTHORS; for details type \`show version'.");
 
 credEntry ceAuthors[] = {
 EOF
@@ -410,6 +409,7 @@ cat >> AUTHORS <<'EOF'
      Ulrich Drepper (an implementation of the public domain MD5 algorithm)
    Bob Jenkins (the ISAAC pseudo random number generator, hashing functions)
        Takuji Nishimura and Makoto Matsumoto (the Mersenne Twister PRNG)
+                   Brian Paul (the TR tile rendering library)
                 Gerry Tesauro (the "pubeval" position evaluator)
              Claes Tornberg (the mec match equity table generator)
 
